scoretemplatetools.ScoreTemplate
================================

.. inheritance-diagram:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate
   :private-bases:

.. autoclass:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__call__

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
